@@ -13,15 +13,10 @@ void* DecodeInterface(int PacketSlot){
 	InterfaceData*	data;
 	PacketRec*		p;
 	
-#ifdef DEBUGPATH
-	printf("In DecodeInterface\n");
-#endif
+	DEBUGPATH;
 
 	p=&Globals.Packets[PacketSlot];
 
-#ifdef DEBUG
-	printf("Decoding the interface\n");
-#endif
 	/*do the decoding*/
 
 	data=(InterfaceData*)malloc(sizeof(InterfaceData));
@@ -36,18 +31,15 @@ void* DecodeInterface(int PacketSlot){
 int InitDecoderInterface(){
 	int DecoderID;
 
-#ifdef DEBUGPATH
-	printf("In InitDecoderInterface\n":);
-#endif
+    DEBUGPATH;
 	
 	if ((DecoderID=CreateDecoder("Interface"))==DECODER_NONE){
-#ifdef DEBUG
-		printf("Couldn't Allocate Decoder Interface\n");
-#endif	
+		DBG( PRINTERROR("Couldn't Allocate Decoder Interface\n") );
 		return FALSE;
 	}
 	
 	Globals.Decoders[DecoderID].DecodeFunc=DecodeInterface;
+	Globals.Decoders[DecoderID].Free=free;
 
 	return TRUE;
 }
