@@ -21,13 +21,7 @@ void* DecodeIP(int PacketSlot){
 	unsigned short	etype;
 	PacketRec*		p;
 	
-#ifdef DEBUGPATH
-	printf("In DecodeEthernetIP\n");
-#endif
-
-#ifdef DEBUG
-	printf("Decoding IP Header\n");
-#endif
+	DEBUGPATH;
 
 	p=&Globals.Packets[PacketSlot];
 
@@ -63,9 +57,7 @@ void* DecodeIP(int PacketSlot){
 int InitDecoderIP(){
 	int DecoderID;
 
-#ifdef DEBUGPATH
-	printf("In InitDecoderIP\n");
-#endif
+	DEBUGPATH;
 	
 	if ((DecoderID=CreateDecoder("IP"))==DECODER_NONE){
 #ifdef DEBUG
@@ -75,6 +67,7 @@ int InitDecoderIP(){
 	}
 	
 	Globals.Decoders[DecoderID].DecodeFunc=DecodeIP;
+	Globals.Decoders[DecoderID].Free=free;
 	if (!DecoderAddDecoder(GetDecoderByName("Ethernet"), DecoderID)){
 		printf("Failed to Bind IP Decoder to Ethernet Decoder\n");
 		return FALSE;
