@@ -194,9 +194,7 @@ int SortFragArray(struct defrag_item* Frags, int NumFrags){
 	int			found;
 	int			last;
 	
-#ifdef DEBUGPATH
-	printf("In SortFragArray\n");
-#endif
+	DEBUGPATH;
 
 	next=0;
 	last=FALSE;
@@ -260,9 +258,7 @@ void* DecodeIPDefrag(int PacketSlot){
 	
 	PacketRec*			p;
 	
-#ifdef DEBUGPATH
-	printf("In DecodeIPDefrag\n");
-#endif
+	DEBUGPATH;
 
 #ifdef DEBUG
 	printf("----------------------------\n");
@@ -392,9 +388,7 @@ void* DecodeIPDefrag(int PacketSlot){
 int InitDecoderIPDefrag(){
 	int DecoderID;
 
-#ifdef DEBUGPATH
-	printf("In InitDecoderIPDefrag\n");
-#endif
+	DEBUGPATH;
 
 	if ((DecoderID=CreateDecoder("IPDefrag"))==DECODER_NONE){
 #ifdef DEBUG
@@ -404,6 +398,7 @@ int InitDecoderIPDefrag(){
 	}
 	
 	Globals.Decoders[DecoderID].DecodeFunc=DecodeIPDefrag;
+	Globals.Decoders[DecoderID].Free=free;
 	if (!DecoderAddDecoder(GetDecoderByName("IP"), DecoderID)){
 		printf("Failed to Bind IP Defrag Decoder to IP Decoder\n");
 		return FALSE;
