@@ -22,13 +22,7 @@ void* DecodeTCPStream(int PacketSlot){
 	PacketRec*		p;
 	
 	
-#ifdef DEBUGPATH
-	printf("In DecodeTCPStream\n");
-#endif
-
-#ifdef DEBUG
-	printf("Decoding TCP Stream\n");
-#endif
+	DEBUGPATH;
 
 	p=&Globals.Packets[PacketSlot];
 
@@ -76,9 +70,7 @@ void* DecodeTCPStream(int PacketSlot){
 int InitDecoderTCPStream(){
 	int DecoderID;
 
-#ifdef DEBUGPATH
-	printf("In InitDecoderTCPStream\n");
-#endif
+	DEBUGPATH;
 	
 	if ((DecoderID=CreateDecoder("TCPStream"))==DECODER_NONE){
 #ifdef DEBUG
@@ -88,6 +80,7 @@ int InitDecoderTCPStream(){
 	}
 	
 	Globals.Decoders[DecoderID].DecodeFunc=DecodeTCPStream;
+	Globals.Decoders[DecoderID].Free=free;
 	if (!DecoderAddDecoder(GetDecoderByName("TCP"), DecoderID)){
 		printf("Failed to Bind TCP Stream Decoder to TCP Decoder\n");
 		return FALSE;
