@@ -25,8 +25,8 @@
 #include <fcntl.h>
 
 //#define DEBUGPATH
-#define DEBUG
-#define DEBUGLOCKS
+//#define DEBUG
+//#define DEBUGLOCKS
 
 GlobalVars Globals;
 
@@ -64,9 +64,8 @@ int CreateTimer(char* Name, unsigned int Interval, int (*TimerFunc)(int TimerID,
 ***************************************/
 void PrintVersion() {
 	printf("\n\nHogwash Light BR (HLBR) v%i.%i\n", MAJOR_VERSION, MINOR_VERSION);
-//	printf("by Andre Bertelli Araujo and\n   Joao Eriberto Mota Filho\n\n");
 	printf("http://hlbr.sourceforge.net\n\n");
-	printf("(Jason Larsen's Hogwash based)\n\n");
+	printf("(Jason Larsen's Hogwash based)\n\n\n");
 }
 
 /*************************************
@@ -74,11 +73,12 @@ void PrintVersion() {
 **************************************/
 void PrintUsage(){
 
-#ifdef DEBUGPATH
-	printf("In PrintUsage\n");
-#endif
+  DEBUGPATH;
+
 	PrintVersion();
 
+	printf("HLBR eh um IPS brasileiro e alguns arquivos possuem frases em portugues e ingles.\n");
+	printf("HLBR is a Brazilian IPS and some files has phrases in portuguese and english.\n\n\n");
 	printf("Utilizacao / Usage:\n");
 	printf("------------------\n");
 	printf("hlbr <args>\n");
@@ -148,9 +148,7 @@ int hlbr_daemon(int nochdir, int noclose){
 int ParseArgs(int argc, char **argv){
 	int 	c;
 	
-#ifdef DEBUGPATH
-	printf("In ParseArgs\n");
-#endif
+	DEBUGPATH;
 
 #define HOG_PARSEARGS_FLAGS "c:r:tn:l:dhv"
 
@@ -279,16 +277,20 @@ int hlbr_mutex_unlock(pthread_mutex_t*	mutex){
 * Handle the signals
 *************************************/
 void HandleSignal(int signal){
-#ifdef DEBUGPATH
-	printf("In HandleSignal\n");
-#endif
 
-	switch (signal){
+  DEBUGPATH;
+
+	switch (signal) {
 	case SIGINT:
 	case SIGQUIT:
 	case SIGTERM:
-		printf("Signal %i recieved. Shutting down pid %i\n", signal, getpid());	
-		Globals.Done=TRUE;
+		printf("Signal %i recieved. Shutting down pid %i\n", signal, getpid());
+		
+		// Removing the pid file
+		if (remove(Globals.PidFilename))
+			fprintf(stderr, "Could not delete Pid file: %s\n", Globals.PidFilename);
+
+		Globals.Done = TRUE;
 		break;
 	}
 }
@@ -388,9 +390,8 @@ int main(int argc, char**argv){
 ***************************************/
 int GetListByName(char* Name){
 	int	i;
-#ifdef DEBUGPATH
-	printf("In GetListByName\n");
-#endif
+
+	DEBUGPATH;
 
 	for (i=0;i<Globals.NumLists;i++){
 		if (strcasecmp(Globals.Lists[i].Name, Name)==0) return i;
@@ -408,9 +409,7 @@ int AddShutdownHandler(int (*func)(void* data), void* data){
 	FuncList*	f;
 	FuncList*	this;
 	
-#ifdef DEBUGPATH
-	printf("In AddShutdownHandler\n");
-#endif
+	DEBUGPATH;
 
 	f=calloc(sizeof(FuncList),1);
 	f->Func=func;
@@ -433,9 +432,7 @@ int AddShutdownHandler(int (*func)(void* data), void* data){
 int CallShutdownHandlers(){
 	FuncList*	this;
 	
-#ifdef DEBUGPATH
-	printf("In CallShutdownHandlers\n");
-#endif
+	DEBUGPATH;
 
 	this=Globals.ShutdownFuncs;
 	while (this){
