@@ -4,9 +4,12 @@
 #include "../routes/route.h"
 #include "../actions/action.h"
 #include "../engine/message.h"
+#include "../decoders/decode.h"
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 #ifdef _SOLARIS_
 #include <strings.h>
 #endif
@@ -26,9 +29,8 @@ int GetLine(FILE* fp, char* buff, int buff_len){
 	char*	Begin;
 	char*	End;
 	
-#ifdef DEBUGPATH
-	printf("In GetLine\n");
-#endif
+	DEBUGPATH;
+
 	bzero(buff, buff_len);
 	Done=FALSE;
 	while (!Done){
@@ -98,9 +100,7 @@ int ParseList(FILE* fp, char* Name, int ListType){
 	int 		ListID;
 	GlobalList*	List;
 	
-#ifdef DEBUGPATH
-	printf("In ParseList\n");
-#endif
+	DEBUGPATH;
 
 	if (!Name) return FALSE;	
 	while (*Name==' ') Name++;
@@ -165,9 +165,7 @@ int ParseAction(FILE* fp, char* Name){
 	char*		Args;
 	char*		Args2;
 	
-#ifdef DEBUGPATH
-	printf("In ParseAction\n");
-#endif
+	DEBUGPATH;
 
 #ifdef DEBUG
 	printf("Parsing Action\n");
@@ -226,6 +224,24 @@ int ParseAction(FILE* fp, char* Name){
 	return FALSE;
 }
 
+int ParsePidFile (char *fname) {
+	FILE *fp;
+	struct stat buffer;
+
+	if (stat(fname, &buffer) == 0){
+		fprintf (stderr, "Pid file found at %s. Please remove it.\n", fname);
+		return FALSE;
+	}
+
+	fp = fopen (fname, "a");
+	fprintf (fp, "%d\n", getpid());
+	fclose (fp);
+
+	Globals.PidFilename = (char *) calloc (strlen(fname), sizeof(char));
+	strcpy (Globals.PidFilename, fname);
+
+	return TRUE;
+}
 
 /*******************************************
 * make sense of the system options
@@ -234,9 +250,7 @@ int ParseSystem(FILE* fp){
 	char		LineBuff[10240];
 	char*		Current;
 	
-#ifdef DEBUGPATH
-	printf("In ParseSystem\n");
-#endif
+	DEBUGPATH;
 
 	/*set the defaults*/
 	if (Globals.SensorName) free(Globals.SensorName);
@@ -253,7 +267,9 @@ int ParseSystem(FILE* fp){
 			return TRUE;
 		}else if (strncasecmp(LineBuff, "name=",5)==0){
 			Current=LineBuff+strlen("name=");
-			if (Globals.SensorName) free(Globals.SensorName);
+
+			if (Globals.SensorName)
+				free(Globals.SensorName);
 			Globals.SensorName=(char*)calloc(strlen(Current)+2, sizeof(char));
 			snprintf(Globals.SensorName, strlen(Current)+1, Current);
 #ifdef DEBUG
@@ -294,7 +310,12 @@ int ParseSystem(FILE* fp){
 			}
 #ifdef DEBUG
 			printf("UseThreads is %i\n",Globals.UseThreads);
-#endif			
+#endif
+		}else if (strncasecmp(LineBuff, "PidFile=", 8) == 0) {
+			Current=LineBuff+8;
+
+			if (!ParsePidFile(Current))
+				return FALSE;
 		}else{
 			printf("Warning: Unknown System Option: %s\n",LineBuff);
 		}
@@ -311,9 +332,7 @@ int ParseInterface(FILE* fp, char* Name){
 	InterfaceRec*	Interface;
 	char*			Current;
 	
-#ifdef DEBUGPATH
-	printf("In ParseInterface\n");
-#endif
+	DEBUGPATH;
 
 	/*get the next free interface*/
 	if (Globals.NumInterfaces==MAX_INTERFACES){
@@ -376,9 +395,7 @@ int ParseRouting(FILE* fp){
 	char*			Pos;
 	char*			Pos2;
 		
-#ifdef DEBUGPATH
-	printf("In ParseRouting\n");
-#endif
+	DEBUGPATH;
 
 	/*set the defaults*/
 
@@ -424,6 +441,26 @@ int ParseRouting(FILE* fp){
 	return FALSE;
 }
 
+int ParseDecoder (FILE *fp, char *decoder) {
+	int			DecoderID;
+
+	DEBUGPATH;
+
+	DecoderID = GetDecoderByName (decoder);
+
+	if (DecoderID == DECODER_NONE) {
+		printf ("There is no decoder called %s\n", decoder);
+		return FALSE;
+	}
+
+	if (Globals.Decoders[DecoderID].ConfigFunction) {
+		if (Globals.Decoders[DecoderID].ConfigFunction(fp))
+			return TRUE;
+	} else
+		printf ("Decoder %s doesn't have configuration options\n", decoder);
+
+	return FALSE;
+}
 
 /*******************************************
 * make sense of the config file
@@ -434,9 +471,7 @@ int ParseConfig(){
 	char*		End;
 	char*		Start;
 	
-#ifdef DEBUGPATH
-	printf("In ParseConfig\n");
-#endif	
+	DEBUGPATH;
 
 	/*set some defaults*/
 	Globals.UseThreads=TRUE;
@@ -481,7 +516,7 @@ int ParseConfig(){
 				return FALSE;
 			}
 			*End=0x00;
-			if (!ParseAction(fp, Start)) return FALSE;									
+			if (!ParseAction(fp, Start)) return FALSE;
 		}else if(strncasecmp(LineBuff, "<module ",8)==0){
 			Start=LineBuff+7;
 			while (*Start==' ') Start++;
@@ -509,6 +544,19 @@ int ParseConfig(){
 			}
 			*End=0x00;		
 			if (!ParseList(fp, Start, LIST_TYPE_IP)) return FALSE;			
+		}else if(strncasecmp(LineBuff, "<decoder ", 9) == 0){
+			Start=LineBuff+9;
+			while(*Start == ' ') Start++;
+			if (*Start == '>') {
+				printf ("Error parsing %s\nFormat <decoder NAME>", LineBuff);
+				return FALSE;
+			}
+			End=strchr(LineBuff+9, '>');
+			if (!End) {
+				printf("Expected \">\"\n");
+			}
+			*End=0x00;
+			if (!ParseDecoder(fp, Start)) return FALSE;
 		}else{
 			printf("Unexpected section %s\n",LineBuff);
 			return FALSE;
